@@ -36,6 +36,7 @@ from pprint import pformat
 import iris
 import iris.coord_categorisation as cat
 import matplotlib.pyplot as plt
+import matplotlib.transforms as mpltrans
 import numpy as np
 from scipy import stats
 
@@ -365,6 +366,8 @@ def plot_slope_regression(cfg, data_dict):
                 pformat(provenance_record))
     with ProvenanceLogger(cfg) as provenance_logger:
         provenance_logger.log(diagnostic_file, provenance_record)
+        provenance_logger.log(get_plot_filename('fig2a', cfg),
+                              provenance_record)
 
     fig, axx = plt.subplots(figsize=(7, 7))
 
@@ -536,6 +539,8 @@ def plot_slope_regression_all(cfg, data_dict, available_vars):
                 pformat(provenance_record))
     with ProvenanceLogger(cfg) as provenance_logger:
         provenance_logger.log(diagnostic_file, provenance_record)
+        provenance_logger.log(get_plot_filename('exfig2a', cfg),
+                              provenance_record)
 
 
 def plot_rlnst_regression(cfg, dataset_name, data, variables, regs):
@@ -609,8 +614,7 @@ def plot_rlnst_regression(cfg, dataset_name, data, variables, regs):
                       'label': yreg_dict["lab_hfss"]},
                      {'color': 'tab:gray',
                       'linestyle': '-'}],
-        save_kwargs={'bbox_inches': 'tight',
-                     'orientation': 'landscape'},
+        save_kwargs={'bbox_inches': mpltrans.Bbox.from_extents(0, -1, 6.5, 6)},
         axes_functions={'set_title': dataset_name,
                         'set_xlabel': '2−m temperature (tas)' +
                                       'global−mean annual anomaly (' +
@@ -670,6 +674,7 @@ def plot_rlnst_regression(cfg, dataset_name, data, variables, regs):
                 pformat(provenance_record))
     with ProvenanceLogger(cfg) as provenance_logger:
         provenance_logger.log(diagnostic_file, provenance_record)
+        provenance_logger.log(filepath, provenance_record)
 
 
 def substract_and_reg_deangelis2(cfg, data, var):
