@@ -1,13 +1,25 @@
 """Function to compare global distributions of turnover time."""
 
 import os.path
-import iris
+
 import cartopy.crs as ccrs
-import matplotlib.pyplot as plt
+import iris
 import matplotlib as mpl
+import matplotlib.pyplot as plt
 import numpy as np
 import scipy.stats as stats
+from iris import NameConstraint
 
+import esmvaltool.diag_scripts.land_carbon_cycle.plot_utils as plut
+from esmvaltool.diag_scripts.land_carbon_cycle.provenance import (
+    _get_ancestor_files,
+    _get_provenance_record,
+)
+from esmvaltool.diag_scripts.land_carbon_cycle.shared import (
+    _apply_common_mask,
+    _load_variable,
+    _remove_invalid,
+)
 from esmvaltool.diag_scripts.shared import (
     ProvenanceLogger,
     get_diagnostic_filename,
@@ -16,18 +28,6 @@ from esmvaltool.diag_scripts.shared import (
     run_diagnostic,
 )
 
-import esmvaltool.diag_scripts.land_carbon_cycle.plot_utils as plut
-from esmvaltool.diag_scripts.land_carbon_cycle.shared import (
-    _apply_common_mask,
-    _load_variable,
-    _remove_invalid,
-    _var_name_constraint,
-)
-from esmvaltool.diag_scripts.land_carbon_cycle.provenance import (
-    _get_ancestor_files,
-    _get_provenance_record,
-)
-
 # set the properties of the lines used for hatching
 mpl.rcParams['hatch.color'] = 'yellow'
 mpl.rcParams['hatch.linewidth'] = 0.7
@@ -230,7 +230,7 @@ def _get_obs_data(diag_config):
     for v_ind in range(nvars):
         var_obs = var_list[v_ind]
         all_data['coords'] = {}
-        variable_constraint = _var_name_constraint(var_obs)
+        variable_constraint = NameConstraint(var_name=var_obs)
         cube = iris.load_cube(input_files, constraint=variable_constraint)
         all_data['grid'][var_obs] = cube
         all_data['global'][var_obs] = fig_config['obs_global']
@@ -275,7 +275,7 @@ def _fix_map(axis_obj):
     """
     axis_obj.set_global()
     axis_obj.coastlines(linewidth=0.4, color='grey')
-    plt.gca().outline_patch.set_visible(False)
+    plt.gca().spines["geo"].set_visible(False)
     return axis_obj
 
 
@@ -427,8 +427,6 @@ def _plot_matrix_map(plot_path_matrix, global_tau_mod, global_tau_obs,
                                len(cb_info_diagonal['tickBounds'])),
                            cmap=cb_info_diagonal['colMap'],
                            origin='upper',
-                           vmin=cb_info_diagonal['tickBounds'][0],
-                           vmax=cb_info_diagonal['tickBounds'][-1],
                            transform=ccrs.PlateCarree())
                 _fix_map(_ax)
 
@@ -467,8 +465,6 @@ def _plot_matrix_map(plot_path_matrix, global_tau_mod, global_tau_obs,
                                cb_info_ratio['tickBounds'],
                                len(cb_info_ratio['tickBounds'])),
                            interpolation='none',
-                           vmin=cb_info_ratio['tickBounds'][0],
-                           vmax=cb_info_ratio['tickBounds'][-1],
                            cmap=cb_info_ratio['colMap'],
                            origin='upper',
                            transform=ccrs.PlateCarree())
@@ -578,8 +574,6 @@ def _plot_multimodel_agreement(plot_path_multimodel, global_tau_mod,
                norm=mpl.colors.BoundaryNorm(cb_info['tickBounds'],
                                             len(cb_info['tickBounds'])),
                interpolation='none',
-               vmin=cb_info['tickBounds'][0],
-               vmax=cb_info['tickBounds'][-1],
                cmap=cb_info['colMap'],
                origin='upper',
                transform=ccrs.PlateCarree())
@@ -662,8 +656,6 @@ def _plot_single_map(plot_path, _dat, _datglobal, _name, provenance_record,
                                             len(cb_info['tickBounds'])),
                cmap=cb_info['colMap'],
                origin='upper',
-               vmin=cb_info['tickBounds'][0],
-               vmax=cb_info['tickBounds'][-1],
                transform=ccrs.PlateCarree())
     _fix_map(_ax)
 
@@ -745,85 +737,79 @@ def main(diag_config):
         tau_global = ctotal_global / gpp_global
         tau_global.convert_units('yr')
 
-        global_tau_mod['global'][model_name] = np.float(tau_global
-                                                        .core_data())
+        global_tau_mod['global'][model_name] = float(tau_global.core_data())
 
-        if diag_config['write_plots']:
-            base_name_mod = (
-                'global_{title}_{source_label}_'
-                '{grid_label}'.format(
-                    title=global_tau_obs['grid']['tau_ctotal'].long_name,
-                    source_label=model_name,
-                    grid_label=diag_config['obs_info']['grid_label']))
-            plot_path_mod = get_plot_filename(base_name_mod, diag_config)
-            # plot_path_list.append(plot_path_mod)
-            provenance_record_mod = _get_provenance_record(
-                "Map of global distribution of turnover time of carbon",
-                ['mean', 'perc'],
-                ['global'],
-                {model_name: model_dataset})
-            _plot_single_map(plot_path_mod, tau_ctotal,
-                             global_tau_mod['global'][model_name],
-                             model_name,
-                             provenance_record_mod,
-                             diag_config)
-        if diag_config['write_netcdf']:
-            model_cubes = [
-                c for c in global_tau_mod['grid'].values()
-                if isinstance(c, iris.cube.Cube)
-            ]
-            obs_cubes = [
-                c for c in global_tau_obs['grid'].values()
-                if isinstance(c, iris.cube.Cube)
-            ]
-            netcdf_path = get_diagnostic_filename(base_name_mod, diag_config)
-            save_cubes = iris.cube.CubeList(model_cubes + obs_cubes)
-            iris.save(save_cubes, netcdf_path)
+        base_name_mod = (
+            'global_{title}_{source_label}_'
+            '{grid_label}'.format(
+                title=global_tau_obs['grid']['tau_ctotal'].long_name,
+                source_label=model_name,
+                grid_label=diag_config['obs_info']['grid_label']))
+        plot_path_mod = get_plot_filename(base_name_mod, diag_config)
+        # plot_path_list.append(plot_path_mod)
+        provenance_record_mod = _get_provenance_record(
+            "Map of global distribution of turnover time of carbon",
+            ['mean', 'perc'],
+            ['global'],
+            {model_name: model_dataset})
+        _plot_single_map(plot_path_mod, tau_ctotal,
+                         global_tau_mod['global'][model_name],
+                         model_name,
+                         provenance_record_mod,
+                         diag_config)
 
-        else:
-            netcdf_path = None
+        model_cubes = [
+            c for c in global_tau_mod['grid'].values()
+            if isinstance(c, iris.cube.Cube)
+        ]
+        obs_cubes = [
+            c for c in global_tau_obs['grid'].values()
+            if isinstance(c, iris.cube.Cube)
+        ]
+        netcdf_path = get_diagnostic_filename(base_name_mod, diag_config)
+        save_cubes = iris.cube.CubeList(model_cubes + obs_cubes)
+        iris.save(save_cubes, netcdf_path)
 
         with ProvenanceLogger(diag_config) as provenance_logger:
             provenance_logger.log(netcdf_path, provenance_record_mod)
 
-    if diag_config['write_plots']:
-        # multimodel agreement
-        base_name_multimodel = '{prefix}_{base_name}'.format(
-            prefix='global_multimodelAgreement', base_name=base_name)
-        plot_path_multimodel = get_plot_filename(base_name_multimodel,
-                                                 diag_config)
-        _plot_multimodel_agreement(plot_path_multimodel, global_tau_mod,
-                                   global_tau_obs, config)
-        with ProvenanceLogger(diag_config) as provenance_logger:
-            provenance_logger.log(plot_path_multimodel,
-                                  provenance_record_multimodel)
+    # multimodel agreement
+    base_name_multimodel = '{prefix}_{base_name}'.format(
+        prefix='global_multimodelAgreement', base_name=base_name)
+    plot_path_multimodel = get_plot_filename(base_name_multimodel,
+                                             diag_config)
+    _plot_multimodel_agreement(plot_path_multimodel, global_tau_mod,
+                               global_tau_obs, config)
+    with ProvenanceLogger(diag_config) as provenance_logger:
+        provenance_logger.log(plot_path_multimodel,
+                              provenance_record_multimodel)
 
-        # map of observation
-        base_name_obs = '{prefix}_{base_name}'.format(prefix='global',
-                                                      base_name=base_name)
-        plot_path_obs = get_plot_filename(base_name_obs, diag_config)
-        provenance_record_obs = _get_provenance_record(
-            "Map of observed global distribution of turnover time of carbon",
-            ['mean', 'perc'],
-            ['global'],
-            global_tau_obs['input_files'].tolist())
+    # map of observation
+    base_name_obs = '{prefix}_{base_name}'.format(prefix='global',
+                                                  base_name=base_name)
+    plot_path_obs = get_plot_filename(base_name_obs, diag_config)
+    provenance_record_obs = _get_provenance_record(
+        "Map of observed global distribution of turnover time of carbon",
+        ['mean', 'perc'],
+        ['global'],
+        global_tau_obs['input_files'].tolist())
 
-        _plot_single_map(plot_path_obs,
-                         global_tau_obs['grid']['tau_ctotal'],
-                         global_tau_obs['global']['tau_ctotal'],
-                         config['obs_info']['source_label'],
-                         provenance_record_obs,
-                         diag_config)
+    _plot_single_map(plot_path_obs,
+                     global_tau_obs['grid']['tau_ctotal'],
+                     global_tau_obs['global']['tau_ctotal'],
+                     config['obs_info']['source_label'],
+                     provenance_record_obs,
+                     diag_config)
 
-        # matrix of maps
-        base_name_matrix = '{prefix}_{base_name}'.format(
-            prefix='global_matrix_map', base_name=base_name)
-        plot_path_matrix = get_plot_filename(base_name_matrix, diag_config)
-        _plot_matrix_map(plot_path_matrix, global_tau_mod, global_tau_obs,
-                         config)
+    # matrix of maps
+    base_name_matrix = '{prefix}_{base_name}'.format(
+        prefix='global_matrix_map', base_name=base_name)
+    plot_path_matrix = get_plot_filename(base_name_matrix, diag_config)
+    _plot_matrix_map(plot_path_matrix, global_tau_mod, global_tau_obs,
+                     config)
 
-        with ProvenanceLogger(diag_config) as provenance_logger:
-            provenance_logger.log(plot_path_matrix, provenance_record_matrix)
+    with ProvenanceLogger(diag_config) as provenance_logger:
+        provenance_logger.log(plot_path_matrix, provenance_record_matrix)
 
 
 if __name__ == '__main__':
