@@ -8,8 +8,39 @@ functionalities of the :ref:`MLR module <api.esmvaltool.diag_scripts.mlr>`. As
 long-term goal we would like to include these functionalities to the
 :mod:`sklearn` package since we believe these additions might be helpful for
 everyone. This module serves as interim solution. To ensure that all features
-are properly working this module is also covered by tests, which will also be
-expanded in the future.
+are properly working this module is also covered by extensive tests.
+
+Parts of this code have been copied from :mod:`sklearn`.
+
+License: BSD 3-Clause License
+
+Copyright (c) 2007-2020 The scikit-learn developers.
+All rights reserved.
+
+Redistribution and use in source and binary forms, with or without
+modification, are permitted provided that the following conditions are met:
+
+* Redistributions of source code must retain the above copyright notice, this
+  list of conditions and the following disclaimer.
+
+* Redistributions in binary form must reproduce the above copyright notice,
+  this list of conditions and the following disclaimer in the documentation
+  and/or other materials provided with the distribution.
+
+* Neither the name of the copyright holder nor the names of its
+  contributors may be used to endorse or promote products derived from this
+  software without specific prior written permission.
+
+THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS" AND
+ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED
+WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE
+DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT HOLDER OR CONTRIBUTORS BE LIABLE
+FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL
+DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR
+SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER
+CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY,
+OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE
+OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 
 """
 
@@ -20,61 +51,335 @@ expanded in the future.
 # pylint: disable=too-many-arguments
 # pylint: disable=too-many-instance-attributes
 # pylint: disable=too-many-locals
+# pylint: disable=too-many-return-statements
 
 import itertools
 import logging
 import numbers
 import os
-import time
 import warnings
 from contextlib import suppress
 from copy import deepcopy
 from inspect import getfullargspec
-from traceback import format_exception_only
+from traceback import format_exc
 
 import numpy as np
+import scipy.sparse as sp
 from joblib import Parallel, delayed, effective_n_jobs
 from sklearn.base import BaseEstimator, clone, is_classifier
 from sklearn.compose import ColumnTransformer, TransformedTargetRegressor
 from sklearn.exceptions import FitFailedWarning, NotFittedError
-from sklearn.feature_selection import RFE
-from sklearn.feature_selection._base import SelectorMixin
+from sklearn.feature_selection import RFE, SelectorMixin
 from sklearn.linear_model import LinearRegression
 from sklearn.metrics import check_scoring
-from sklearn.metrics._scorer import (
-    _check_multimetric_scoring,
-    _MultimetricScorer,
-)
 from sklearn.model_selection import check_cv
-from sklearn.model_selection._validation import _aggregate_score_dicts, _score
 from sklearn.pipeline import Pipeline
-from sklearn.utils import (
-    _message_with_time,
-    check_array,
-    check_X_y,
-    indexable,
-    safe_sqr,
-)
-from sklearn.utils.metaestimators import _safe_split, if_delegate_has_method
-from sklearn.utils.validation import _check_fit_params, check_is_fitted
+from sklearn.preprocessing import FunctionTransformer
+from sklearn.utils import check_array, check_X_y, indexable, safe_sqr
+from sklearn.utils.fixes import np_version, parse_version
+from sklearn.utils.metaestimators import available_if
+from sklearn.utils.validation import check_is_fitted
 
 from esmvaltool.diag_scripts import mlr
 
 logger = logging.getLogger(os.path.basename(__file__))
 
 
-def _fit_and_score_weighted(estimator, x_data, y_data, scorer, train, test,
-                            verbose, parameters, fit_params,
-                            error_score=np.nan, sample_weights=None):
-    """Expand :func:`sklearn.model_selection._validation._fit_and_score`."""
-    if verbose > 1:
-        if parameters is None:
-            msg = ''
-        else:
-            msg = '%s' % (', '.join('%s=%s' % (k, v)
-                                    for k, v in parameters.items()))
-        print("[CV] %s %s" % (msg, (64 - len(msg)) * '.'))
+_DEFAULT_TAGS = {
+    'non_deterministic': False,
+    'requires_positive_X': False,
+    'requires_positive_y': False,
+    'X_types': ['2darray'],
+    'poor_score': False,
+    'no_validation': False,
+    'multioutput': False,
+    "allow_nan": False,
+    'stateless': False,
+    'multilabel': False,
+    '_skip_test': False,
+    '_xfail_checks': False,
+    'multioutput_only': False,
+    'binary_only': False,
+    'requires_fit': True,
+    'preserves_dtype': [np.float64],
+    'requires_y': False,
+    'pairwise': False,
+}
 
+
+def _estimator_has(attr):
+    """Check if we can delegate a method to the underlying estimator.
+
+    First, we check the first fitted estimator if available, otherwise we
+    check the unfitted estimator.
+
+    """
+    return lambda self: (
+        hasattr(self.estimator_, attr)
+        if hasattr(self, "estimator_")
+        else hasattr(self.estimator, attr)
+    )
+
+
+def _determine_key_type(key, accept_slice=True):
+    """Determine the data type of key."""
+    err_msg = ("No valid specification of the columns. Only a scalar, list or "
+               "slice of all integers or all strings, or boolean mask is "
+               "allowed")
+
+    dtype_to_str = {int: 'int', str: 'str', bool: 'bool', np.bool_: 'bool'}
+    array_dtype_to_str = {'i': 'int', 'u': 'int', 'b': 'bool', 'O': 'str',
+                          'U': 'str', 'S': 'str'}
+
+    if key is None:
+        return None
+    if isinstance(key, tuple(dtype_to_str.keys())):
+        try:
+            return dtype_to_str[type(key)]
+        except KeyError as exc:
+            raise ValueError(err_msg) from exc
+    if isinstance(key, slice):
+        if not accept_slice:
+            raise TypeError(
+                'Only array-like or scalar are supported. '
+                'A Python slice was given.'
+            )
+        if key.start is None and key.stop is None:
+            return None
+        key_start_type = _determine_key_type(key.start)
+        key_stop_type = _determine_key_type(key.stop)
+        if key_start_type is not None and key_stop_type is not None:
+            if key_start_type != key_stop_type:
+                raise ValueError(err_msg)
+        if key_start_type is not None:
+            return key_start_type
+        return key_stop_type
+    if isinstance(key, (list, tuple)):
+        unique_key = set(key)
+        key_type = {_determine_key_type(elt) for elt in unique_key}
+        if not key_type:
+            return None
+        if len(key_type) != 1:
+            raise ValueError(err_msg)
+        return key_type.pop()
+    if hasattr(key, 'dtype'):
+        try:
+            return array_dtype_to_str[key.dtype.kind]
+        except KeyError as exc:
+            raise ValueError(err_msg) from exc
+    raise ValueError(err_msg)
+
+
+def _array_indexing(array, key, key_dtype, axis):
+    """Index an array or scipy.sparse consistently across numpy version."""
+    if np_version < parse_version('1.12') or sp.issparse(array):
+        if key_dtype == 'bool':
+            key = np.asarray(key)
+    if isinstance(key, tuple):
+        key = list(key)
+    return array[key] if axis == 0 else array[:, key]
+
+
+def _list_indexing(x_data, key, key_dtype):
+    """Index a python list."""
+    if np.isscalar(key) or isinstance(key, slice):
+        # key is a slice or a scalar
+        return x_data[key]
+    if key_dtype == 'bool':
+        # key is a boolean array-like
+        return list(itertools.compress(x_data, key))
+    # key is a integer array-like of key
+    return [x_data[idx] for idx in key]
+
+
+def _pandas_indexing(x_data, key, key_dtype, axis):
+    """Index a pandas dataframe or a series."""
+    if hasattr(key, 'shape'):
+        key = np.asarray(key)
+        key = key if key.flags.writeable else key.copy()
+    elif isinstance(key, tuple):
+        key = list(key)
+    # check whether we should index with loc or iloc
+    indexer = x_data.iloc if key_dtype == 'int' else x_data.loc
+    return indexer[:, key] if axis else indexer[key]
+
+
+def _safe_indexing(x_data, indices, *_, axis=0):
+    """Return rows, items or columns of x_data using indices."""
+    if indices is None:
+        return x_data
+
+    if axis not in (0, 1):
+        raise ValueError(
+            f"'axis' should be either 0 (to index rows) or 1 (to index "
+            f"column). Got {axis} instead."
+        )
+
+    indices_dtype = _determine_key_type(indices)
+
+    if axis == 0 and indices_dtype == 'str':
+        raise ValueError(
+            "String indexing is not supported with 'axis=0'"
+        )
+
+    if axis == 1 and x_data.ndim != 2:
+        raise ValueError(
+            f"'x_data' should be a 2D NumPy array, 2D sparse matrix or pandas "
+            f"dataframe when indexing the columns (i.e. 'axis=1'). "
+            f"Got {type(x_data)} instead with {x_data.ndim} dimension(s)."
+        )
+
+    if axis == 1 and indices_dtype == 'str' and not hasattr(x_data, 'loc'):
+        raise ValueError(
+            "Specifying the columns using strings is only supported for "
+            "pandas DataFrames"
+        )
+
+    if hasattr(x_data, "iloc"):
+        return _pandas_indexing(x_data, indices, indices_dtype, axis=axis)
+    if hasattr(x_data, "shape"):
+        return _array_indexing(x_data, indices, indices_dtype, axis=axis)
+    return _list_indexing(x_data, indices, indices_dtype)
+
+
+def _is_arraylike(input_array):
+    """Check whether the input is array-like."""
+    return (hasattr(input_array, '__len__') or
+            hasattr(input_array, 'shape') or
+            hasattr(input_array, '__array__'))
+
+
+def _make_indexable(iterable):
+    """Ensure iterable supports indexing or convert to an indexable variant."""
+    if sp.issparse(iterable):
+        return iterable.tocsr()
+    if hasattr(iterable, "__getitem__") or hasattr(iterable, "iloc"):
+        return iterable
+    if iterable is None:
+        return iterable
+    return np.array(iterable)
+
+
+def _num_samples(x_data):
+    """Return number of samples in array-like x_data."""
+    message = f"Expected sequence or array-like, got {type(x_data)}"
+    if hasattr(x_data, 'fit') and callable(x_data.fit):
+        # Don't get num_samples from an ensembles length!
+        raise TypeError(message)
+
+    if not hasattr(x_data, '__len__') and not hasattr(x_data, 'shape'):
+        if hasattr(x_data, '__array__'):
+            x_data = np.asarray(x_data)
+        else:
+            raise TypeError(message)
+
+    if hasattr(x_data, 'shape') and x_data.shape is not None:
+        if len(x_data.shape) == 0:
+            raise TypeError(
+                f"Singleton array {x_data!r} cannot be considered a valid "
+                f"collection."
+            )
+        # Check that shape is returning an integer or default to len
+        # Dask dataframes may not return numeric shape[0] value
+        if isinstance(x_data.shape[0], numbers.Integral):
+            return x_data.shape[0]
+
+    try:
+        return len(x_data)
+    except TypeError as type_error:
+        raise TypeError(message) from type_error
+
+
+def _check_fit_params(x_data, fit_params, indices=None):
+    """Check and validate the parameters passed during ``fit``."""
+    fit_params_validated = {}
+    for param_key, param_value in fit_params.items():
+        if (not _is_arraylike(param_value) or
+                _num_samples(param_value) != _num_samples(x_data)):
+            # Non-indexable pass-through (for now for backward-compatibility).
+            # https://github.com/scikit-learn/scikit-learn/issues/15805
+            fit_params_validated[param_key] = param_value
+        else:
+            # Any other fit_params should support indexing
+            # (e.g. for cross-validation).
+            fit_params_validated[param_key] = _make_indexable(param_value)
+            fit_params_validated[param_key] = _safe_indexing(
+                fit_params_validated[param_key], indices
+            )
+
+    return fit_params_validated
+
+
+def _safe_tags(estimator, key=None):
+    """Safely get estimator tags."""
+    if hasattr(estimator, "_get_tags"):
+        tags_provider = "_get_tags()"
+        tags = estimator._get_tags()
+    elif hasattr(estimator, "_more_tags"):
+        tags_provider = "_more_tags()"
+        tags = {**_DEFAULT_TAGS, **estimator._more_tags()}
+    else:
+        tags_provider = "_DEFAULT_TAGS"
+        tags = _DEFAULT_TAGS
+
+    if key is not None:
+        if key not in tags:
+            raise ValueError(
+                f"The key {key} is not defined in {tags_provider} for the "
+                f"class {estimator.__class__.__name__}."
+            )
+        return tags[key]
+    return tags
+
+
+def _is_pairwise(estimator):
+    """Return ``True`` if estimator is pairwise."""
+    with warnings.catch_warnings():
+        warnings.filterwarnings('ignore', category=FutureWarning)
+        has_pairwise_attribute = hasattr(estimator, '_pairwise')
+        pairwise_attribute = getattr(estimator, '_pairwise', False)
+    pairwise_tag = _safe_tags(estimator, key="pairwise")
+
+    if has_pairwise_attribute:
+        if pairwise_attribute != pairwise_tag:
+            warnings.warn(
+                "_pairwise attribute is inconsistent with tags. Set the "
+                "estimator tags of your estimator instead", FutureWarning,
+            )
+        return pairwise_attribute
+
+    # Use pairwise tag when the attribute is not present
+    return pairwise_tag
+
+
+def _safe_split(estimator, x_data, y_data, indices, train_indices=None):
+    """Create subset of dataset and properly handle kernels."""
+    if _is_pairwise(estimator):
+        if not hasattr(x_data, "shape"):
+            raise ValueError("Precomputed kernels or affinity matrices have "
+                             "to be passed as arrays or sparse matrices.")
+        # x_data is a precomputed square kernel matrix
+        if x_data.shape[0] != x_data.shape[1]:
+            raise ValueError("x_data should be a square kernel matrix")
+        if train_indices is None:
+            x_subset = x_data[np.ix_(indices, indices)]
+        else:
+            x_subset = x_data[np.ix_(indices, train_indices)]
+    else:
+        x_subset = _safe_indexing(x_data, indices)
+
+    if y_data is not None:
+        y_subset = _safe_indexing(y_data, indices)
+    else:
+        y_subset = None
+
+    return (x_subset, y_subset)
+
+
+def _fit_and_score_weighted(estimator, x_data, y_data, scorer, train, test,
+                            parameters, fit_params, error_score=np.nan,
+                            sample_weights=None):
+    """Expand :func:`sklearn.model_selection._validation._fit_and_score`."""
     # Adjust length of sample weights
     fit_params = fit_params if fit_params is not None else {}
     fit_params = _check_fit_params(x_data, fit_params, train)
@@ -89,10 +394,8 @@ def _fit_and_score_weighted(estimator, x_data, y_data, scorer, train, test,
 
         estimator = estimator.set_params(**cloned_parameters)
 
-    start_time = time.time()
-
-    x_train, y_train = _safe_split(estimator, x_data, y_data, train)
-    x_test, y_test = _safe_split(estimator, x_data, y_data, test, train)
+    (x_train, y_train) = _safe_split(estimator, x_data, y_data, train)
+    (x_test, y_test) = _safe_split(estimator, x_data, y_data, test, train)
     if sample_weights is not None:
         sample_weights_test = sample_weights[test]
     else:
@@ -103,48 +406,26 @@ def _fit_and_score_weighted(estimator, x_data, y_data, scorer, train, test,
             estimator.fit(x_train, **fit_params)
         else:
             estimator.fit(x_train, y_train, **fit_params)
-
     except Exception as exc:
-        # Note fit time as time until error
-        fit_time = time.time() - start_time
-        score_time = 0.0
         if error_score == 'raise':
             raise
         if isinstance(error_score, numbers.Number):
-            if isinstance(scorer, dict):
-                test_scores = {name: error_score for name in scorer}
-            else:
-                test_scores = error_score
-            warnings.warn("Estimator fit failed. The score on this train-test"
-                          " partition for these parameters will be set to %f. "
-                          "Details: \n%s" %
-                          (error_score, format_exception_only(type(exc),
-                                                              exc)[0]),
-                          FitFailedWarning)
+            test_score = error_score
+            warnings.warn(
+                f"Estimator fit failed. The score on this train-test "
+                f"partition for these parameters will be set to "
+                f"{error_score:f}. Details: \n{format_exc()}",
+                FitFailedWarning)
         else:
-            raise ValueError("error_score must be the string 'raise' or a"
-                             " numeric value. (Hint: if using 'raise', please"
-                             " make sure that it has been spelled correctly.)")
-
+            raise ValueError(
+                "error_score must be the string 'raise' or a "
+                "numeric value. (Hint: if using 'raise', please "
+                "make sure that it has been spelled correctly.)") from exc
     else:
-        fit_time = time.time() - start_time
-        test_scores = _score_weighted(estimator, x_test, y_test, scorer,
-                                      sample_weights=sample_weights_test)
-        score_time = time.time() - start_time - fit_time
-    if verbose > 2:
-        if isinstance(test_scores, dict):
-            for scorer_name in sorted(test_scores):
-                msg += ", %s=" % scorer_name
-                msg += "%.3f" % test_scores[scorer_name]
-        else:
-            msg += ", score="
-            msg += "%.3f" % test_scores
+        test_score = _score_weighted(estimator, x_test, y_test, scorer,
+                                     sample_weights=sample_weights_test)
 
-    if verbose > 1:
-        total_time = score_time + fit_time
-        print(_message_with_time('CV', msg, total_time))
-
-    return [test_scores]
+    return test_score
 
 
 def _get_fit_parameters(fit_kwargs, steps, cls):
@@ -160,13 +441,65 @@ def _get_fit_parameters(fit_kwargs, steps, cls):
                 f"of the parameter, got '{param_name}'")
         try:
             params[param_split[0]][param_split[1]] = param_val
-        except KeyError:
+        except KeyError as exc:
             raise ValueError(
                 f"Expected one of {step_names} for step of fit parameter, got "
-                f"'{param_split[0]}' for parameter '{param_name}'")
+                f"'{param_split[0]}' for parameter '{param_name}'") from exc
     return params
 
 
+def _score_weighted(estimator, x_test, y_test, scorer, sample_weights=None):
+    """Expand :func:`sklearn.model_selection._validation._score`."""
+    if y_test is None:
+        score = scorer(estimator, x_test, sample_weight=sample_weights)
+    else:
+        score = scorer(estimator, x_test, y_test, sample_weight=sample_weights)
+
+    error_msg = ("Scoring must return a number, got %s (%s) instead. "
+                 "(scorer=%s)")
+    if hasattr(score, 'item'):
+        with suppress(ValueError):
+            # e.g. unwrap memmapped scalars
+            score = score.item()
+    if not isinstance(score, numbers.Number):
+        raise ValueError(error_msg % (score, type(score), scorer))
+    return score
+
+
+def _split_fit_kwargs(fit_kwargs, train_idx, test_idx):
+    """Get split fit kwargs for single CV step."""
+    fit_kwargs_train = {}
+    fit_kwargs_test = {}
+    for (key, val) in fit_kwargs.items():
+        if 'sample_weight' in key and 'sample_weight_eval_set' not in key:
+            fit_kwargs_train[key] = deepcopy(val)[train_idx]
+            fit_kwargs_test[key] = deepcopy(val)[test_idx]
+        else:
+            fit_kwargs_train[key] = deepcopy(val)
+            fit_kwargs_test[key] = deepcopy(val)
+    return (fit_kwargs_train, fit_kwargs_test)
+
+
+def _rfe_single_fit(rfe, estimator, x_data, y_data, train, test, scorer,
+                    **fit_kwargs):
+    """Return the score for a fit across one fold."""
+    (x_train, y_train) = _safe_split(estimator, x_data, y_data, train)
+    (x_test, y_test) = _safe_split(estimator, x_data, y_data, test, train)
+    (fit_kwargs_train, fit_kwargs_test) = _split_fit_kwargs(fit_kwargs, train,
+                                                            test)
+    if 'sample_weight' in fit_kwargs_test:
+        fit_kwargs_test['sample_weights'] = fit_kwargs_test.pop(
+            'sample_weight')
+
+    def step_score(estimator, features):
+        """Score for a single step in the recursive feature elimination."""
+        return _score_weighted(estimator, x_test[:, features], y_test, scorer,
+                               **fit_kwargs_test)
+
+    return rfe._fit(x_train, y_train, step_score=step_score,
+                    **fit_kwargs_train).scores_
+
+
 def _map_features(features, support):
     """Map old features indices to new ones using boolean mask."""
     feature_mapping = {}
@@ -186,67 +519,6 @@ def _map_features(features, support):
     return new_features
 
 
-def _rfe_single_fit(rfe, estimator, x_data, y_data, train, test, scorer,
-                    **fit_kwargs):
-    """Return the score for a fit across one fold."""
-    (x_train, y_train) = _safe_split(estimator, x_data, y_data, train)
-    (x_test, y_test) = _safe_split(estimator, x_data, y_data, test, train)
-    (fit_kwargs_train, _) = _split_fit_kwargs(fit_kwargs, train, test)
-
-    def step_score(estimator, features):
-        """Score for a single step in the recursive feature elimination."""
-        return _score(estimator, x_test[:, features], y_test, scorer)
-
-    return rfe._fit(x_train, y_train, step_score=step_score,
-                    **fit_kwargs_train).scores_
-
-
-def _score_weighted(estimator, x_test, y_test, scorer, sample_weights=None):
-    """Expand :func:`sklearn.model_selection._validation._score`."""
-    if isinstance(scorer, dict):
-        # will cache method calls if needed. scorer() returns a dict
-        scorer = _MultimetricScorer(**scorer)
-    if y_test is None:
-        scores = scorer(estimator, x_test, sample_weight=sample_weights)
-    else:
-        scores = scorer(estimator, x_test, y_test,
-                        sample_weight=sample_weights)
-
-    error_msg = ("scoring must return a number, got %s (%s) "
-                 "instead. (scorer=%s)")
-    if isinstance(scores, dict):
-        for name, score in scores.items():
-            if hasattr(score, 'item'):
-                with suppress(ValueError):
-                    # e.g. unwrap memmapped scalars
-                    score = score.item()
-            if not isinstance(score, numbers.Number):
-                raise ValueError(error_msg % (score, type(score), name))
-            scores[name] = score
-    else:  # scalar
-        if hasattr(scores, 'item'):
-            with suppress(ValueError):
-                # e.g. unwrap memmapped scalars
-                scores = scores.item()
-        if not isinstance(scores, numbers.Number):
-            raise ValueError(error_msg % (scores, type(scores), scorer))
-    return scores
-
-
-def _split_fit_kwargs(fit_kwargs, train_idx, test_idx):
-    """Get split fit kwargs for single CV step."""
-    fit_kwargs_train = {}
-    fit_kwargs_test = {}
-    for (key, val) in fit_kwargs.items():
-        if 'sample_weight' in key and 'sample_weight_eval_set' not in key:
-            fit_kwargs_train[key] = deepcopy(val)[train_idx]
-            fit_kwargs_test[key] = deepcopy(val)[test_idx]
-        else:
-            fit_kwargs_train[key] = deepcopy(val)
-            fit_kwargs_test[key] = deepcopy(val)
-    return (fit_kwargs_train, fit_kwargs_test)
-
-
 def _update_transformers_param(estimator, support):
     """Update ``transformers`` argument of ``ColumnTransformer`` steps."""
     all_params = estimator.get_params()
@@ -283,12 +555,9 @@ def cross_val_score_weighted(estimator, x_data, y_data=None, groups=None,
                              error_score=np.nan, sample_weights=None):
     """Expand :func:`sklearn.model_selection.cross_val_score`."""
     scorer = check_scoring(estimator, scoring=scoring)
-    scorer_name = 'score'
-    scoring = {scorer_name: scorer}
-    x_data, y_data, groups = indexable(x_data, y_data, groups)
+    (x_data, y_data, groups) = indexable(x_data, y_data, groups)
 
     cv = check_cv(cv, y_data, classifier=is_classifier(estimator))
-    scorers, _ = _check_multimetric_scoring(estimator, scoring=scoring)
 
     # We clone the estimator to make sure that all the folds are
     # independent, and that it is pickle-able.
@@ -296,25 +565,20 @@ def cross_val_score_weighted(estimator, x_data, y_data=None, groups=None,
                         pre_dispatch=pre_dispatch)
     scores = parallel(
         delayed(_fit_and_score_weighted)(
-            clone(estimator), x_data, y_data, scorers, train, test, verbose,
-            None, fit_params, error_score=error_score,
-            sample_weights=sample_weights)
+            clone(estimator), x_data, y_data, scorer, train, test, None,
+            fit_params, error_score=error_score, sample_weights=sample_weights)
         for train, test in cv.split(x_data, y_data, groups))
-
-    test_scores = list(zip(*scores))[0]
-    test_scores = _aggregate_score_dicts(test_scores)
-
-    return np.array(test_scores[scorer_name])
+    return np.array(scores)
 
 
 def get_rfecv_transformer(rfecv_estimator):
     """Get transformer step of RFECV estimator."""
     try:
         check_is_fitted(rfecv_estimator)
-    except NotFittedError:
+    except NotFittedError as exc:
         raise NotFittedError(
             "RFECV instance used to initialize FeatureSelectionTransformer "
-            "must be fitted")
+            "must be fitted") from exc
     transformer = FeatureSelectionTransformer(
         grid_scores=rfecv_estimator.grid_scores_,
         n_features=rfecv_estimator.n_features_,
@@ -445,10 +709,9 @@ class AdvancedRFE(RFE):
         # step_score is not exposed to users
         # and is used when implementing AdvancedRFECV
         # self.scores_ will not be calculated when calling _fit through fit
-        tags = self._get_tags()
-        x_data, y_data = check_X_y(
-            x_data, y_data, "csc", ensure_min_features=2,
-            force_all_finite=not tags.get('allow_nan', True))
+        x_data, y_data = check_X_y(x_data, y_data, "csc",
+                                   ensure_min_features=2,
+                                   force_all_finite=False)
 
         # Initialization
         n_features = x_data.shape[1]
@@ -464,8 +727,8 @@ class AdvancedRFE(RFE):
         if step <= 0:
             raise ValueError("Step must be >0")
 
-        support_ = np.ones(n_features, dtype=np.bool)
-        ranking_ = np.ones(n_features, dtype=np.int)
+        support_ = np.ones(n_features, dtype=bool)
+        ranking_ = np.ones(n_features, dtype=np.int64)
 
         if step_score:
             self.scores_ = []
@@ -478,7 +741,7 @@ class AdvancedRFE(RFE):
             # Rank the remaining features
             estimator = clone(self.estimator)
             if self.verbose > 0:
-                print("Fitting estimator with %d features." % np.sum(support_))
+                print(f"Fitting estimator with {np.sum(support_):d} features.")
 
             _update_transformers_param(estimator, support_)
             estimator.fit(x_data[:, features], y_data, **fit_kwargs)
@@ -490,9 +753,9 @@ class AdvancedRFE(RFE):
             except (AttributeError, KeyError):
                 coefs = getattr(estimator, 'feature_importances_', None)
             if coefs is None:
-                raise RuntimeError('The classifier does not expose '
-                                   '"coef_" or "feature_importances_" '
-                                   'attributes')
+                raise RuntimeError("The classifier does not expose "
+                                   "'coef_' or 'feature_importances_' "
+                                   "attributes")
 
             # Get ranks
             if coefs.ndim > 1:
@@ -500,6 +763,16 @@ class AdvancedRFE(RFE):
             else:
                 ranks = np.argsort(safe_sqr(coefs))
 
+            # Transformer steps that reduce number of features is not supported
+            if len(ranks) != len(features):
+                raise NotImplementedError(
+                    f"Estimators that contain transforming steps that reduce "
+                    f"the number of features are not supported in "
+                    f"{self.__class__}, got {len(features):d} features for ",
+                    f"fit(), but only {len(ranks):d} elements for 'coefs_' / "
+                    f"'feature_importances_' are provided. Estimator:\n"
+                    f"{estimator}")
+
             # for sparse case ranks is matrix
             ranks = np.ravel(ranks)
 
@@ -529,7 +802,7 @@ class AdvancedRFE(RFE):
 
         return self
 
-    @if_delegate_has_method(delegate='estimator')
+    @available_if(_estimator_has("predict"))
     def predict(self, x_data, **predict_kwargs):
         """Expand :meth:`predict()` to accept kwargs."""
         check_is_fitted(self)
@@ -545,11 +818,11 @@ class AdvancedRFECV(AdvancedRFE):
         """Original constructor of :class:`sklearn.feature_selection.RFECV`."""
         self.estimator = estimator
         self.step = step
+        self.min_features_to_select = min_features_to_select
         self.cv = cv
         self.scoring = scoring
         self.verbose = verbose
         self.n_jobs = n_jobs
-        self.min_features_to_select = min_features_to_select
 
     def fit(self, x_data, y_data, groups=None, **fit_kwargs):
         """Expand :meth:`fit` to accept kwargs."""
@@ -558,7 +831,8 @@ class AdvancedRFECV(AdvancedRFE):
             force_all_finite=False)
 
         # Initialization
-        cv = check_cv(self.cv, y_data, is_classifier(self.estimator))
+        cv = check_cv(self.cv, y_data,
+                      classifier=is_classifier(self.estimator))
         scorer = check_scoring(self.estimator, scoring=self.scoring)
         n_features = x_data.shape[1]
 
@@ -585,10 +859,10 @@ class AdvancedRFECV(AdvancedRFE):
         # This branching is done so that to
         # make sure that user code that sets n_jobs to 1
         # and provides bound methods as scorers is not broken with the
-        # addition of n_jobs parameter in version 0.18.
+        # addition of n_jobs parameter.
 
         if effective_n_jobs(self.n_jobs) == 1:
-            parallel, func = list, _rfe_single_fit
+            (parallel, func) = (list, _rfe_single_fit)
         else:
             parallel = Parallel(n_jobs=self.n_jobs)
             func = delayed(_rfe_single_fit)
@@ -741,6 +1015,8 @@ class AdvancedTransformedTargetRegressor(TransformedTargetRegressor):
             ('regressor', self.regressor),
         ]
         fit_params = _get_fit_parameters(fit_kwargs, steps, self.__class__)
+        fit_params.setdefault('transformer', {})
+        fit_params.setdefault('regressor', {})
 
         # FIXME
         if fit_params['transformer']:
@@ -751,6 +1027,34 @@ class AdvancedTransformedTargetRegressor(TransformedTargetRegressor):
 
         return (fit_params['transformer'], fit_params['regressor'])
 
+    def _fit_transformer(self, y_data):
+        """Check transformer and fit transformer."""
+        if (self.transformer is not None and
+                (self.func is not None or self.inverse_func is not None)):
+            raise ValueError("'transformer' and functions 'func'/"
+                             "'inverse_func' cannot both be set.")
+        if self.transformer is not None:
+            self.transformer_ = clone(self.transformer)
+        else:
+            if self.func is not None and self.inverse_func is None:
+                raise ValueError(
+                    "When 'func' is provided, 'inverse_func' must also be "
+                    "provided")
+            self.transformer_ = FunctionTransformer(
+                func=self.func, inverse_func=self.inverse_func, validate=True,
+                check_inverse=self.check_inverse)
+        self.transformer_.fit(y_data)
+        if self.check_inverse:
+            idx_selected = slice(None, None, max(1, y_data.shape[0] // 10))
+            y_sel = _safe_indexing(y_data, idx_selected)
+            y_sel_t = self.transformer_.transform(y_sel)
+            if not np.allclose(y_sel,
+                               self.transformer_.inverse_transform(y_sel_t)):
+                warnings.warn("The provided functions or transformer are "
+                              "not strictly inverse of each other. If "
+                              "you are sure you want to proceed regardless, "
+                              "set 'check_inverse=False'", UserWarning)
+
     def _to_be_squeezed(self, array, always_return_1d=True):
         """Check if ``array`` should be squeezed or not."""
         squeeze = array.ndim == 2 and array.shape[1] == 1
@@ -779,6 +1083,6 @@ class FeatureSelectionTransformer(BaseEstimator, SelectorMixin):
 
     def _more_tags(self):
         """Additional estimator tags."""
-        more_tags = super()._more_tags()
+        more_tags = deepcopy(_DEFAULT_TAGS)
         more_tags['allow_nan'] = True
         return more_tags
