@@ -14,6 +14,9 @@ Currently supported plot types (use the option ``plots`` to specify them):
     - Time series (plot type ``timeseries``): for each variable separately, all
       datasets are plotted in one single figure. Input data needs to be 1D with
       single dimension `time`.
+    - Annual cycle (plot type ``annual_cycle``): for each variable separately,
+      all datasets are plotted in one single figure. Input data needs to be 1D
+      with single dimension `month_number`.
     - Maps (plot type ``map``): for each variable and dataset, an individual
       map is plotted. If a reference dataset is defined, also include this
       dataset and a bias plot into the figure. Note that if a reference dataset
@@ -48,9 +51,9 @@ figure_kwargs: dict, optional
     default, uses ``constrained_layout: true``.
 plots: dict, optional
     Plot types plotted by this diagnostic (see list above). Dictionary keys
-    must be ``timeseries``, ``map``, or ``profile``. Dictionary values are
-    dictionaries used as options for the corresponding plot. The allowed
-    options for the different plot types are given below.
+    must be ``timeseries``, ``annual_cycle``, ``map``, or ``profile``.
+    Dictionary values are dictionaries used as options for the corresponding
+    plot. The allowed options for the different plot types are given below.
 plot_filename: str, optional
     Filename pattern for the plots.
     Defaults to ``{plot_type}_{real_name}_{dataset}_{mip}_{exp}_{ensemble}``.
@@ -101,6 +104,31 @@ pyplot_kwargs: dict, optional
     to something like  ``ambiguous_project``. Examples: ``title: 'Awesome Plot
     of {long_name}'``, ``xlabel: '{short_name}'``, ``xlim: [0, 5]``.
 
+Configuration options for plot type ``annual_cycle``
+----------------------------------------------------
+legend_kwargs: dict, optional
+    Optional keyword arguments for :func:`matplotlib.pyplot.legend`. Use
+    ``legend_kwargs: false`` to not show legends.
+plot_kwargs: dict, optional
+    Optional keyword arguments for :func:`iris.plot.plot`. Dictionary keys are
+    elements identified by ``facet_used_for_labels`` or ``default``, e.g.,
+    ``CMIP6`` if ``facet_used_for_labels: project`` or ``historical`` if
+    ``facet_used_for_labels: exp``. Dictionary values are dictionaries used as
+    keyword arguments for :func:`iris.plot.plot`. String arguments can include
+    facets in curly brackets which will be derived from the corresponding
+    dataset, e.g., ``{project}``, ``{short_name}``, ``{exp}``. Examples:
+    ``default: {linestyle: '-', label: '{project}'}, CMIP6: {color: red,
+    linestyle: '--'}, OBS: {color: black}``.
+pyplot_kwargs: dict, optional
+    Optional calls to functions of :mod:`matplotlib.pyplot`. Dictionary keys
+    are functions of :mod:`matplotlib.pyplot`. Dictionary values are used as
+    single argument for these functions. String arguments can include facets in
+    curly brackets which will be derived from the datasets plotted in the
+    corresponding plot, e.g., ``{short_name}``, ``{exp}``. Facets like
+    ``{project}`` that vary between the different datasets will be transformed
+    to something like  ``ambiguous_project``. Examples: ``title: 'Awesome Plot
+    of {long_name}'``, ``xlabel: '{short_name}'``, ``xlim: [0, 5]``.
+
 Configuration options for plot type ``map``
 -------------------------------------------
 cbar_label: str, optional (default: '{short_name} [{units}]')
@@ -177,6 +205,14 @@ rasterize: bool, optional (default: True)
     graphics (e.g., ``output_file_type=pdf,svg,ps``).
 show_stats: bool, optional (default: True)
     Show basic statistics on the plots.
+x_pos_stats_avg: float, optional (default: 0.0)
+    Text x-position of average (shown on the left) in Axes coordinates. Can be
+    adjusted to avoid overlap with the figure. Only relevant if ``show_stats:
+    true``.
+x_pos_stats_bias: float, optional (default: 0.92)
+    Text x-position of bias statistics (shown on the right) in Axes
+    coordinates. Can be adjusted to avoid overlap with the figure. Only
+    relevant if ``show_stats: true``.
 
 Configuration options for plot type ``profile``
 -----------------------------------------------
@@ -247,6 +283,14 @@ show_y_minor_ticklabels: bool, optional (default: False)
     Show tick labels for the minor ticks on the Y axis.
 show_stats: bool, optional (default: True)
     Show basic statistics on the plots.
+x_pos_stats_avg: float, optional (default: 0.01)
+    Text x-position of average (shown on the left) in Axes coordinates. Can be
+    adjusted to avoid overlap with the figure. Only relevant if ``show_stats:
+    true``.
+x_pos_stats_bias: float, optional (default: 0.7)
+    Text x-position of bias statistics (shown on the right) in Axes
+    coordinates. Can be adjusted to avoid overlap with the figure. Only
+    relevant if ``show_stats: true``.
 
 .. hint::
 
@@ -277,7 +321,9 @@ import esmvaltool.diag_scripts.shared.iris_helpers as ih
 from esmvaltool.diag_scripts.monitor.monitor_base import MonitorBase
 from esmvaltool.diag_scripts.shared import (
     ProvenanceLogger,
+    get_diagnostic_filename,
     group_metadata,
+    io,
     run_diagnostic,
 )
 
@@ -306,10 +352,19 @@ class MultiDatasets(MonitorBase):
 
         # Load input data
         self.input_data = self._load_and_preprocess_data()
-        self.grouped_input_data = group_metadata(self.input_data, 'short_name')
+        self.grouped_input_data = group_metadata(
+            self.input_data,
+            'short_name',
+            sort=self.cfg['facet_used_for_labels'],
+        )
 
         # Check given plot types and set default settings for them
-        self.supported_plot_types = ['timeseries', 'map', 'profile']
+        self.supported_plot_types = [
+            'timeseries',
+            'annual_cycle',
+            'map',
+            'profile',
+        ]
         for (plot_type, plot_options) in self.plots.items():
             if plot_type not in self.supported_plot_types:
                 raise ValueError(
@@ -330,11 +385,18 @@ class MultiDatasets(MonitorBase):
                 self.plots[plot_type].setdefault('rasterize', True)
                 self.plots[plot_type].setdefault('show_stats', True)
 
-            # Defaults profile plots
+            # Defaults for map plots
+            if plot_type == 'map':
+                self.plots[plot_type].setdefault('x_pos_stats_avg', 0.0)
+                self.plots[plot_type].setdefault('x_pos_stats_bias', 0.92)
+
+            # Defaults for profile plots
             if plot_type == 'profile':
                 self.plots[plot_type].setdefault('log_y', True)
                 self.plots[plot_type].setdefault('show_y_minor_ticklabels',
                                                  False)
+                self.plots[plot_type].setdefault('x_pos_stats_avg', 0.01)
+                self.plots[plot_type].setdefault('x_pos_stats_bias', 0.7)
 
         # Check that facet_used_for_labels is present for every dataset
         for dataset in self.input_data:
@@ -374,20 +436,31 @@ class MultiDatasets(MonitorBase):
             cbar_right.set_label(cbar_label_right, fontsize=fontsize)
             cbar_right.ax.tick_params(labelsize=fontsize)
 
-    def _add_stats(self, plot_type, axes, dim_coords, cube, ref_cube=None):
+    def _add_stats(self, plot_type, axes, dim_coords, dataset,
+                   ref_dataset=None):
         """Add text to plot that describes basic statistics."""
         if not self.plots[plot_type]['show_stats']:
             return
 
+        # Extract cube(s)
+        cube = dataset['cube']
+        if ref_dataset is None:
+            ref_cube = None
+            label = self._get_label(dataset)
+        else:
+            ref_cube = ref_dataset['cube']
+            label = (f'{self._get_label(dataset)} vs. '
+                     f'{self._get_label(ref_dataset)}')
+
         # Different options for the different plots types
         fontsize = 6.0
         y_pos = 0.95
         if plot_type == 'map':
-            x_pos_bias = 0.92
-            x_pos = 0.0
+            x_pos_bias = self.plots[plot_type]['x_pos_stats_bias']
+            x_pos = self.plots[plot_type]['x_pos_stats_avg']
         elif plot_type == 'profile':
-            x_pos_bias = 0.7
-            x_pos = 0.01
+            x_pos_bias = self.plots[plot_type]['x_pos_stats_bias']
+            x_pos = self.plots[plot_type]['x_pos_stats_avg']
         else:
             raise NotImplementedError(f"plot_type '{plot_type}' not supported")
 
@@ -410,9 +483,23 @@ class MultiDatasets(MonitorBase):
         if ref_cube is None:
             mean = cube.collapsed(dim_coords, iris.analysis.MEAN,
                                   weights=weights)
+            logger.info(
+                "Area-weighted mean of %s for %s = %f%s",
+                dataset['short_name'],
+                label,
+                mean.data,
+                dataset['units'],
+            )
         else:
             mean = (cube - ref_cube).collapsed(dim_coords, iris.analysis.MEAN,
                                                weights=weights)
+            logger.info(
+                "Area-weighted bias of %s for %s = %f%s",
+                dataset['short_name'],
+                label,
+                mean.data,
+                dataset['units'],
+            )
         axes.text(x_pos, y_pos, f"{mean.data:.2f}{cube.units}",
                   fontsize=fontsize, transform=axes.transAxes)
         if ref_cube is None:
@@ -423,6 +510,13 @@ class MultiDatasets(MonitorBase):
                                            weights=weights)
         axes.text(x_pos_bias, y_pos, f"RMSE={rmse.data:.2f}{cube.units}",
                   fontsize=fontsize, transform=axes.transAxes)
+        logger.info(
+            "Area-weighted RMSE of %s for %s = %f%s",
+            dataset['short_name'],
+            label,
+            rmse.data,
+            dataset['units'],
+        )
 
         # Weighted R2
         mask = np.ma.getmaskarray(cube.data).ravel()
@@ -433,6 +527,12 @@ class MultiDatasets(MonitorBase):
         r2_val = r2_score(cube_data, ref_cube_data, sample_weight=weights)
         axes.text(x_pos_bias, y_pos - 0.1, rf"R$^2$={r2_val:.2f}",
                   fontsize=fontsize, transform=axes.transAxes)
+        logger.info(
+            "Area-weighted R2 of %s for %s = %f",
+            dataset['short_name'],
+            label,
+            r2_val,
+        )
 
     def _get_custom_mpl_rc_params(self, plot_type):
         """Get custom matplotlib rcParams."""
@@ -543,7 +643,7 @@ class MultiDatasets(MonitorBase):
                 plot_kwargs[key] = val
 
         # Default settings for different plot types
-        if plot_type == 'timeseries':
+        if plot_type in ('timeseries', 'annual_cycle'):
             plot_kwargs.setdefault('label', label)
 
         return deepcopy(plot_kwargs)
@@ -570,12 +670,6 @@ class MultiDatasets(MonitorBase):
                 z_coord = cube.coord('altitude')
                 z_coord.attributes['positive'] = 'up'
 
-            # Convert pr units if necessary
-            if cube.var_name == 'pr' and cube.units == 'kg m-2 s-1':
-                cube.units = 'mm s-1'
-                cube.convert_units('mm day-1')
-                dataset['units'] = 'mm day-1'
-
             dataset['cube'] = cube
 
         return input_data
@@ -583,8 +677,8 @@ class MultiDatasets(MonitorBase):
     def _plot_map_with_ref(self, plot_func, dataset, ref_dataset):
         """Plot map plot for single dataset with a reference dataset."""
         plot_type = 'map'
-        logger.debug("Plotting map with reference dataset '%s' for '%s'",
-                     self._get_label(ref_dataset), self._get_label(dataset))
+        logger.info("Plotting map with reference dataset '%s' for '%s'",
+                    self._get_label(ref_dataset), self._get_label(dataset))
 
         # Make sure that the data has the correct dimensions
         cube = dataset['cube']
@@ -613,7 +707,7 @@ class MultiDatasets(MonitorBase):
             if gridline_kwargs is not False:
                 axes_data.gridlines(**gridline_kwargs)
             axes_data.set_title(self._get_label(dataset), pad=3.0)
-            self._add_stats(plot_type, axes_data, dim_coords_dat, cube)
+            self._add_stats(plot_type, axes_data, dim_coords_dat, dataset)
 
             # Plot reference dataset (top right)
             # Note: make sure to use the same vmin and vmax than the top left
@@ -629,7 +723,7 @@ class MultiDatasets(MonitorBase):
             if gridline_kwargs is not False:
                 axes_ref.gridlines(**gridline_kwargs)
             axes_ref.set_title(self._get_label(ref_dataset), pad=3.0)
-            self._add_stats(plot_type, axes_ref, dim_coords_ref, ref_cube)
+            self._add_stats(plot_type, axes_ref, dim_coords_ref, ref_dataset)
 
             # Add colorbar(s)
             self._add_colorbar(plot_type, plot_data, plot_ref, axes_data,
@@ -658,8 +752,8 @@ class MultiDatasets(MonitorBase):
                 fontsize=fontsize,
             )
             cbar_bias.ax.tick_params(labelsize=fontsize)
-            self._add_stats(plot_type, axes_bias, dim_coords_dat, cube,
-                            ref_cube)
+            self._add_stats(plot_type, axes_bias, dim_coords_dat, dataset,
+                            ref_dataset)
 
             # Customize plot
             fig.suptitle(f"{dataset['long_name']} ({dataset['start_year']}-"
@@ -670,13 +764,24 @@ class MultiDatasets(MonitorBase):
             if self.plots[plot_type]['rasterize']:
                 self._set_rasterized([axes_data, axes_ref, axes_bias])
 
-        return self.get_plot_path(plot_type, dataset)
+        # File paths
+        plot_path = self.get_plot_path(plot_type, dataset)
+        netcdf_path = (
+            get_diagnostic_filename(Path(plot_path).stem + "_{pos}", self.cfg)
+        )
+        netcdf_paths = {
+            netcdf_path.format(pos='top_left'): cube,
+            netcdf_path.format(pos='top_right'): ref_cube,
+            netcdf_path.format(pos='bottom'): bias_cube,
+        }
+
+        return (plot_path, netcdf_paths)
 
     def _plot_map_without_ref(self, plot_func, dataset):
         """Plot map plot for single dataset without a reference dataset."""
         plot_type = 'map'
-        logger.debug("Plotting map without reference dataset for '%s'",
-                     self._get_label(dataset))
+        logger.info("Plotting map without reference dataset for '%s'",
+                    self._get_label(dataset))
 
         # Make sure that the data has the correct dimensions
         cube = dataset['cube']
@@ -695,7 +800,7 @@ class MultiDatasets(MonitorBase):
                 axes.gridlines(**gridline_kwargs)
 
             # Print statistics if desired
-            self._add_stats(plot_type, axes, dim_coords_dat, cube)
+            self._add_stats(plot_type, axes, dim_coords_dat, dataset)
 
             # Setup colorbar
             fontsize = self.plots[plot_type]['fontsize']
@@ -715,13 +820,17 @@ class MultiDatasets(MonitorBase):
             if self.plots[plot_type]['rasterize']:
                 self._set_rasterized([axes])
 
-        return self.get_plot_path(plot_type, dataset)
+        # File paths
+        plot_path = self.get_plot_path(plot_type, dataset)
+        netcdf_path = get_diagnostic_filename(Path(plot_path).stem, self.cfg)
+
+        return (plot_path, {netcdf_path: cube})
 
     def _plot_profile_with_ref(self, plot_func, dataset, ref_dataset):
         """Plot profile plot for single dataset with a reference dataset."""
         plot_type = 'profile'
-        logger.debug("Plotting profile with reference dataset '%s' for '%s'",
-                     self._get_label(ref_dataset), self._get_label(dataset))
+        logger.info("Plotting profile with reference dataset '%s' for '%s'",
+                    self._get_label(ref_dataset), self._get_label(dataset))
 
         # Make sure that the data has the correct dimensions
         cube = dataset['cube']
@@ -755,7 +864,7 @@ class MultiDatasets(MonitorBase):
                     FormatStrFormatter('%.1f'))
             else:
                 axes_data.get_yaxis().set_minor_formatter(NullFormatter())
-            self._add_stats(plot_type, axes_data, dim_coords_dat, cube)
+            self._add_stats(plot_type, axes_data, dim_coords_dat, dataset)
 
             # Plot reference dataset (top right)
             # Note: make sure to use the same vmin and vmax than the top left
@@ -769,7 +878,7 @@ class MultiDatasets(MonitorBase):
             plot_ref = plot_func(ref_cube, **plot_kwargs)
             axes_ref.set_title(self._get_label(ref_dataset), pad=3.0)
             plt.setp(axes_ref.get_yticklabels(), visible=False)
-            self._add_stats(plot_type, axes_ref, dim_coords_ref, ref_cube)
+            self._add_stats(plot_type, axes_ref, dim_coords_ref, ref_dataset)
 
             # Add colorbar(s)
             self._add_colorbar(plot_type, plot_data, plot_ref, axes_data,
@@ -797,8 +906,8 @@ class MultiDatasets(MonitorBase):
                 fontsize=fontsize,
             )
             cbar_bias.ax.tick_params(labelsize=fontsize)
-            self._add_stats(plot_type, axes_bias, dim_coords_dat, cube,
-                            ref_cube)
+            self._add_stats(plot_type, axes_bias, dim_coords_dat, dataset,
+                            ref_dataset)
 
             # Customize plot
             fig.suptitle(f"{dataset['long_name']} ({dataset['start_year']}-"
@@ -809,13 +918,24 @@ class MultiDatasets(MonitorBase):
             if self.plots[plot_type]['rasterize']:
                 self._set_rasterized([axes_data, axes_ref, axes_bias])
 
-        return self.get_plot_path(plot_type, dataset)
+        # File paths
+        plot_path = self.get_plot_path(plot_type, dataset)
+        netcdf_path = (
+            get_diagnostic_filename(Path(plot_path).stem + "_{pos}", self.cfg)
+        )
+        netcdf_paths = {
+            netcdf_path.format(pos='top_left'): cube,
+            netcdf_path.format(pos='top_right'): ref_cube,
+            netcdf_path.format(pos='bottom'): bias_cube,
+        }
+
+        return (plot_path, netcdf_paths)
 
     def _plot_profile_without_ref(self, plot_func, dataset):
         """Plot profile plot for single dataset without a reference dataset."""
         plot_type = 'profile'
-        logger.debug("Plotting profile without reference dataset for '%s'",
-                     self._get_label(dataset))
+        logger.info("Plotting profile without reference dataset for '%s'",
+                    self._get_label(dataset))
 
         # Make sure that the data has the correct dimensions
         cube = dataset['cube']
@@ -830,7 +950,7 @@ class MultiDatasets(MonitorBase):
             plot_profile = plot_func(cube, **plot_kwargs)
 
             # Print statistics if desired
-            self._add_stats(plot_type, axes, dim_coords_dat, cube)
+            self._add_stats(plot_type, axes, dim_coords_dat, dataset)
 
             # Setup colorbar
             fontsize = self.plots[plot_type]['fontsize']
@@ -862,7 +982,11 @@ class MultiDatasets(MonitorBase):
             if self.plots[plot_type]['rasterize']:
                 self._set_rasterized([axes])
 
-        return self.get_plot_path(plot_type, dataset)
+        # File paths
+        plot_path = self.get_plot_path(plot_type, dataset)
+        netcdf_path = get_diagnostic_filename(Path(plot_path).stem, self.cfg)
+
+        return (plot_path, {netcdf_path: cube})
 
     def _process_pyplot_kwargs(self, plot_type, dataset):
         """Process functions for :mod:`matplotlib.pyplot`."""
@@ -880,6 +1004,7 @@ class MultiDatasets(MonitorBase):
     def _check_cube_dimensions(cube, plot_type):
         """Check that cube has correct dimensional variables."""
         expected_dimensions_dict = {
+            'annual_cycle': (['month_number'],),
             'map': (['latitude', 'longitude'],),
             'profile': (['latitude', 'air_pressure'],
                         ['latitude', 'altitude']),
@@ -951,9 +1076,11 @@ class MultiDatasets(MonitorBase):
 
         # Plot all datasets in one single figure
         ancestors = []
+        cubes = {}
         for dataset in datasets:
             ancestors.append(dataset['filename'])
             cube = dataset['cube']
+            cubes[self._get_label(dataset)] = cube
             self._check_cube_dimensions(cube, plot_type)
 
             # Plot original time series
@@ -994,6 +1121,13 @@ class MultiDatasets(MonitorBase):
         logger.info("Wrote %s", plot_path)
         plt.close()
 
+        # Save netCDF file
+        netcdf_path = get_diagnostic_filename(Path(plot_path).stem, self.cfg)
+        var_attrs = {
+            n: datasets[0][n] for n in ('short_name', 'long_name', 'units')
+        }
+        io.save_1d_data(cubes, netcdf_path, 'time', var_attrs)
+
         # Provenance tracking
         caption = (f"Time series of {multi_dataset_facets['long_name']} for "
                    f"various datasets.")
@@ -1005,6 +1139,75 @@ class MultiDatasets(MonitorBase):
         }
         with ProvenanceLogger(self.cfg) as provenance_logger:
             provenance_logger.log(plot_path, provenance_record)
+            provenance_logger.log(netcdf_path, provenance_record)
+
+    def create_annual_cycle_plot(self, datasets, short_name):
+        """Create annual cycle plot."""
+        plot_type = 'annual_cycle'
+        if plot_type not in self.plots:
+            return
+
+        if not datasets:
+            raise ValueError(f"No input data to plot '{plot_type}' given")
+
+        logger.info("Plotting %s", plot_type)
+        fig = plt.figure(**self.cfg['figure_kwargs'])
+        axes = fig.add_subplot()
+
+        # Plot all datasets in one single figure
+        ancestors = []
+        cubes = {}
+        for dataset in datasets:
+            ancestors.append(dataset['filename'])
+            cube = dataset['cube']
+            cubes[self._get_label(dataset)] = cube
+            self._check_cube_dimensions(cube, plot_type)
+
+            # Plot annual cycle
+            plot_kwargs = self._get_plot_kwargs(plot_type, dataset)
+            plot_kwargs['axes'] = axes
+            iris.plot.plot(cube, **plot_kwargs)
+
+        # Default plot appearance
+        multi_dataset_facets = self._get_multi_dataset_facets(datasets)
+        axes.set_title(multi_dataset_facets['long_name'])
+        axes.set_xlabel('Month')
+        axes.set_ylabel(f"{short_name} [{multi_dataset_facets['units']}]")
+        axes.set_xticks(range(1, 13), [str(m) for m in range(1, 13)])
+
+        # Legend
+        legend_kwargs = self.plots[plot_type].get('legend_kwargs', {})
+        if legend_kwargs is not False:
+            axes.legend(**legend_kwargs)
+
+        # Customize plot appearance
+        self._process_pyplot_kwargs(plot_type, multi_dataset_facets)
+
+        # Save plot
+        plot_path = self.get_plot_path(plot_type, multi_dataset_facets)
+        fig.savefig(plot_path, **self.cfg['savefig_kwargs'])
+        logger.info("Wrote %s", plot_path)
+        plt.close()
+
+        # Save netCDF file
+        netcdf_path = get_diagnostic_filename(Path(plot_path).stem, self.cfg)
+        var_attrs = {
+            n: datasets[0][n] for n in ('short_name', 'long_name', 'units')
+        }
+        io.save_1d_data(cubes, netcdf_path, 'month_number', var_attrs)
+
+        # Provenance tracking
+        caption = (f"Annual cycle of {multi_dataset_facets['long_name']} for "
+                   f"various datasets.")
+        provenance_record = {
+            'ancestors': ancestors,
+            'authors': ['schlund_manuel'],
+            'caption': caption,
+            'plot_types': ['seas'],
+        }
+        with ProvenanceLogger(self.cfg) as provenance_logger:
+            provenance_logger.log(plot_path, provenance_record)
+            provenance_logger.log(netcdf_path, provenance_record)
 
     def create_map_plot(self, datasets, short_name):
         """Create map plot."""
@@ -1033,15 +1236,18 @@ class MultiDatasets(MonitorBase):
                 continue
             ancestors = [dataset['filename']]
             if ref_dataset is None:
-                plot_path = self._plot_map_without_ref(plot_func, dataset)
+                (plot_path, netcdf_paths) = (
+                    self._plot_map_without_ref(plot_func, dataset)
+                )
                 caption = (
                     f"Map plot of {dataset['long_name']} of dataset "
                     f"{dataset['dataset']} (project {dataset['project']}) "
                     f"from {dataset['start_year']} to {dataset['end_year']}."
                 )
             else:
-                plot_path = self._plot_map_with_ref(plot_func, dataset,
-                                                    ref_dataset)
+                (plot_path, netcdf_paths) = (
+                    self._plot_map_with_ref(plot_func, dataset, ref_dataset)
+                )
                 caption = (
                     f"Map plot of {dataset['long_name']} of dataset "
                     f"{dataset['dataset']} (project {dataset['project']}) "
@@ -1062,6 +1268,10 @@ class MultiDatasets(MonitorBase):
             logger.info("Wrote %s", plot_path)
             plt.close()
 
+            # Save netCDFs
+            for (netcdf_path, cube) in netcdf_paths.items():
+                io.iris_save(cube, netcdf_path)
+
             # Provenance tracking
             provenance_record = {
                 'ancestors': ancestors,
@@ -1071,6 +1281,8 @@ class MultiDatasets(MonitorBase):
             }
             with ProvenanceLogger(self.cfg) as provenance_logger:
                 provenance_logger.log(plot_path, provenance_record)
+                for netcdf_path in netcdf_paths:
+                    provenance_logger.log(netcdf_path, provenance_record)
 
     def create_profile_plot(self, datasets, short_name):
         """Create profile plot."""
@@ -1099,15 +1311,19 @@ class MultiDatasets(MonitorBase):
                 continue
             ancestors = [dataset['filename']]
             if ref_dataset is None:
-                plot_path = self._plot_profile_without_ref(plot_func, dataset)
+                (plot_path, netcdf_paths) = (
+                    self._plot_profile_without_ref(plot_func, dataset)
+                )
                 caption = (
                     f"Vertical profile of {dataset['long_name']} of dataset "
                     f"{dataset['dataset']} (project {dataset['project']}) "
                     f"from {dataset['start_year']} to {dataset['end_year']}."
                 )
             else:
-                plot_path = self._plot_profile_with_ref(plot_func, dataset,
-                                                        ref_dataset)
+                (plot_path, netcdf_paths) = (
+                    self._plot_profile_with_ref(plot_func, dataset,
+                                                ref_dataset)
+                )
                 caption = (
                     f"Vertical profile of {dataset['long_name']} of dataset "
                     f"{dataset['dataset']} (project {dataset['project']}) "
@@ -1128,6 +1344,10 @@ class MultiDatasets(MonitorBase):
             logger.info("Wrote %s", plot_path)
             plt.close()
 
+            # Save netCDFs
+            for (netcdf_path, cube) in netcdf_paths.items():
+                io.iris_save(cube, netcdf_path)
+
             # Provenance tracking
             provenance_record = {
                 'ancestors': ancestors,
@@ -1137,12 +1357,15 @@ class MultiDatasets(MonitorBase):
             }
             with ProvenanceLogger(self.cfg) as provenance_logger:
                 provenance_logger.log(plot_path, provenance_record)
+                for netcdf_path in netcdf_paths:
+                    provenance_logger.log(netcdf_path, provenance_record)
 
     def compute(self):
         """Plot preprocessed data."""
         for (short_name, datasets) in self.grouped_input_data.items():
             logger.info("Processing variable %s", short_name)
             self.create_timeseries_plot(datasets, short_name)
+            self.create_annual_cycle_plot(datasets, short_name)
             self.create_map_plot(datasets, short_name)
             self.create_profile_plot(datasets, short_name)
 
