@@ -1,16 +1,12 @@
 """Convenience functions for :mod:`iris` objects."""
 import logging
-import warnings
 from pprint import pformat
 
 import iris
 import numpy as np
 from cf_units import Unit
-from iris import NameConstraint
 from iris.exceptions import CoordinateNotFoundError
 
-from esmvaltool import ESMValToolDeprecationWarning
-
 from ._base import group_metadata
 
 logger = logging.getLogger(__name__)
@@ -371,35 +367,3 @@ def unify_time_coord(cube, target_units='days since 1850-01-01 00:00:00'):
     coord_dims = cube.coord_dims('time')
     cube.remove_coord('time')
     cube.add_dim_coord(new_time_coord, coord_dims)
-
-
-def var_name_constraint(var_name):
-    """:class:`iris.Constraint` using ``var_name``.
-
-    Warning
-    -------
-    .. deprecated:: 2.6.0
-        This function has been deprecated in ESMValTool version 2.6.0 and is
-        scheduled for removal in version 2.8.0. Please use the function
-        :class:`iris.NameConstraint` with the argument ``var_name`` instead:
-        this is an exact replacement.
-
-    Parameters
-    ----------
-    var_name: str
-        ``var_name`` used for the constraint.
-
-    Returns
-    -------
-    iris.Constraint
-        Constraint.
-
-    """
-    deprecation_msg = (
-        "The function ``var_name_constraint`` has been deprecated in "
-        "ESMValTool version 2.6.0 and is scheduled for removal in version "
-        "2.8.0. Please use the function ``iris.NameConstraint`` with the "
-        "argument ``var_name`` instead: this is an exact replacement."
-    )
-    warnings.warn(deprecation_msg, ESMValToolDeprecationWarning)
-    return NameConstraint(var_name=var_name)
